bowl.cli_opts.version — bowl 0.2.0 documentation

### Navigation

- index
- modules |
- bowl 0.2.0 documentation »
- Module code »

# Source code for bowl.cli_opts.version

    """
    This module is the version command of bowl.

    Created on 14 March 2014
    @author: Charlie Lewis
    """

    import pkg_resources

    class version(object):
        """
        This class is responsible for the version command of the cli.
        """
        @classmethod
        def main(self, args):
            print pkg_resources.get_distribution("bowl").version
            return pkg_resources.get_distribution("bowl").version

### Navigation

- index
- modules |
- bowl 0.2.0 documentation »
- Module code »